@@ -294,7 +294,7 @@ class Syn_Error():
         result = f'{_Style.RESET_ALL}{_Fore.RED}{_Style.BRIGHT}-{lang["exceptions"]["syntaxheader"]}{"-" * max([size[0] - len(lang["exceptions"]["syntaxheader"]) - 1, 0])}{_Style.RESET_ALL}\n'
         result += f'{_Style.RESET_ALL}{_Fore.BLUE}{_Style.BRIGHT}An error occured while lexing and parsing:{_Style.RESET_ALL}\n'
         result += f'  {_Fore.GREEN}File{_Style.RESET_ALL} {_Fore.GREEN}{_Style.BRIGHT}{self.start.file}{_Style.RESET_ALL}\n'
-        result += f'    {_Fore.GREEN}Line{_Style.RESET_ALL} {_Fore.GREEN}{_Style.BRIGHT}{self.start.line}{_Style.RESET_ALL}, {_Fore.GREEN}Column{_Style.RESET_ALL} {_Fore.GREEN}{_Style.BRIGHT}{self.start.column}{_Style.RESET_ALL}\n'
+        result += f'    {_Fore.GREEN}Line{_Style.RESET_ALL} {_Fore.GREEN}{_Style.BRIGHT}{self.start.line + 1}{_Style.RESET_ALL}, {_Fore.GREEN}Column{_Style.RESET_ALL} {_Fore.GREEN}{_Style.BRIGHT}{self.start.column + 1}{_Style.RESET_ALL}\n'
         result += f'      {_Fore.YELLOW}{_Style.BRIGHT}{self.start.lntext}{_Style.RESET_ALL}\n'
         result += f'      {" " * self.start.column}{_Fore.YELLOW}{"^" * (self.end.column - self.start.column)}{_Style.RESET_ALL}\n'
 
